{% extends "django_classified/_base.html" %}

{% load i18n bootstrap %}

{% block title %}{% trans "Profile" %}{% endblock title %}

{% block body %}
  <div class="row marketing">
    <div class="col-lg-12">
      <form method="post" role="form">
        {% csrf_token %}
        {{ form|bootstrap }}
        <input type="submit" value="{% trans "Update" %}" class="btn">
      </form>
    </div>
  </div>
{% endblock %}